"use client"

import { GeminiClient } from "@/lib/gemini-client"

// This is the AI dispatcher that connects to the Gemini API
export class AIDispatcher {
  private static geminiClient = GeminiClient.getInstance()
  private static isInitialized = false

  // Initialize the API client with the API key
  static initialize(apiKey: string) {
    if (!this.isInitialized) {
      this.geminiClient.setApiKey(apiKey)
      this.isInitialized = true
      console.log("AI Dispatcher initialized with API key")
    }
  }

  // Generate assistant response
  static async generateAssistantResponse(userMessage: string): Promise<string> {
    try {
      console.log("AI Dispatcher: Generating assistant response for:", userMessage)
      return await this.geminiClient.generateAssistantResponse(userMessage)
    } catch (error) {
      console.error("Error generating assistant response:", error)
      return "Przepraszam, wystąpił błąd podczas generowania odpowiedzi. Spróbuj ponownie za chwilę."
    }
  }

  // Generate technical prompt
  static async generateTechnicalPrompt(userMessage: string): Promise<string> {
    try {
      console.log("AI Dispatcher: Generating technical prompt for:", userMessage)
      return await this.geminiClient.generateTechnicalPrompt(userMessage)
    } catch (error) {
      console.error("Error generating technical prompt:", error)
      throw new Error("Nie udało się wygenerować technicznego promptu")
    }
  }

  // Send prompt to programmer
  static async sendPromptToProgrammer(prompt: string): Promise<{ output: string; status: string }> {
    try {
      console.log("AI Dispatcher: Sending prompt to AI Programmer:", prompt)
      return await this.geminiClient.generateCode(prompt)
    } catch (error) {
      console.error("Error generating code:", error)
      return {
        output: "// Wystąpił błąd podczas generowania kodu\nconsole.error('Błąd generowania kodu');",
        status: "error",
      }
    }
  }
}
