"use client"

import { useState } from "react"
import { useRouter } from "next/navigation"
import {
  Dialog,
  DialogContent,
  DialogDescription,
  DialogHeader,
  DialogTitle,
  DialogFooter,
} from "@/components/ui/dialog"
import { Button } from "@/components/ui/button"
import { Input } from "@/components/ui/input"
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue } from "@/components/ui/select"
import { Code, Github } from "lucide-react"

interface WebAppCreatorProps {
  isOpen: boolean
  onClose: () => void
}

export function WebAppCreator({ isOpen, onClose }: WebAppCreatorProps) {
  const router = useRouter()
  const [projectName, setProjectName] = useState("")
  const [framework, setFramework] = useState("next")
  const [template, setTemplate] = useState("default")

  const handleContinue = () => {
    if (!projectName) return

    // Navigate to the studio page
    router.push("/studio")
    onClose()
  }

  return (
    <Dialog open={isOpen} onOpenChange={(open) => !open && onClose()}>
      <DialogContent className="sm:max-w-[500px]">
        <DialogHeader>
          <DialogTitle>Create Web Application</DialogTitle>
          <DialogDescription>Enter basic information to get started with your web application</DialogDescription>
        </DialogHeader>

        <div className="grid gap-4 py-4">
          <div className="space-y-2">
            <label htmlFor="project-name" className="text-sm font-medium">
              Project Name
            </label>
            <Input
              id="project-name"
              value={projectName}
              onChange={(e) => setProjectName(e.target.value)}
              placeholder="my-awesome-app"
              autoFocus
            />
          </div>

          <div className="space-y-2">
            <label htmlFor="framework" className="text-sm font-medium">
              Framework
            </label>
            <Select value={framework} onValueChange={setFramework}>
              <SelectTrigger>
                <SelectValue placeholder="Select framework" />
              </SelectTrigger>
              <SelectContent>
                <SelectItem value="next">Next.js</SelectItem>
                <SelectItem value="react">React</SelectItem>
                <SelectItem value="vue">Vue</SelectItem>
                <SelectItem value="svelte">Svelte</SelectItem>
              </SelectContent>
            </Select>
          </div>

          <div className="space-y-2">
            <label htmlFor="template" className="text-sm font-medium">
              Template
            </label>
            <Select value={template} onValueChange={setTemplate}>
              <SelectTrigger>
                <SelectValue placeholder="Select template" />
              </SelectTrigger>
              <SelectContent>
                <SelectItem value="default">Default</SelectItem>
                <SelectItem value="blog">Blog</SelectItem>
                <SelectItem value="ecommerce">E-commerce</SelectItem>
                <SelectItem value="dashboard">Dashboard</SelectItem>
              </SelectContent>
            </Select>
          </div>

          <div className="flex items-center gap-2 mt-2">
            <Code className="h-5 w-5 text-gray-500" />
            <span className="text-sm text-gray-500">
              You'll be able to edit code and see live preview in the studio
            </span>
          </div>

          <div className="flex items-center gap-2">
            <Github className="h-5 w-5 text-gray-500" />
            <span className="text-sm text-gray-500">GitHub integration available for pushing your project</span>
          </div>
        </div>

        <DialogFooter>
          <Button variant="outline" onClick={onClose}>
            Cancel
          </Button>
          <Button onClick={handleContinue} disabled={!projectName}>
            Continue to Studio
          </Button>
        </DialogFooter>
      </DialogContent>
    </Dialog>
  )
}
